"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapTask = void 0;
const logging_1 = require("./logging");
// Set up log emitter listening from SDK, proper error catching and throwing of SDK errors
function wrapTask(func) {
    return (ctx, task) => {
        const teardownTaskListeners = (0, logging_1.logToTaskOutput)(task);
        return func(ctx, task)
            .then(() => {
            teardownTaskListeners();
        })
            .catch((error) => {
            teardownTaskListeners();
            // Format message as human-readable listr output
            const formattedMessage = (0, logging_1.formatLogMessageOneLine)({
                ts: (new Date()).toJSON(),
                level: 'error',
                error
            });
            const enrichedError = new Error(formattedMessage);
            // Attach original error object for error log
            enrichedError.originalError = error;
            throw enrichedError;
        });
    };
}
exports.wrapTask = wrapTask;
